Begin a column layout section.

To move to the next column use [ImGuiNextColumn]. To end a column layout section pass `1` to this function.

**Note:** Current implementation supports a maximum of 64 columns.